@@ -1,10 +1,10 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.model import ModelSQL, fields
-from trytond.pyson import Eval
-from trytond.pool import PoolMeta
 from trytond.modules.company.model import (
     CompanyMultiValueMixin, CompanyValueMixin)
+from trytond.pool import PoolMeta
+from trytond.pyson import Eval
 
 
 class Configuration(CompanyMultiValueMixin, metaclass=PoolMeta):
@@ -27,5 +27,4 @@ class ConfigurationSalePriceList(ModelSQL, CompanyValueMixin):
         'product.price_list', "Sale Price List",
         domain=[
             ('company', '=', Eval('company', -1)),
-            ],
-        depends=['company'])
+            ])
