@@ -1,8 +1,8 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.model import fields
-from trytond.transaction import Transaction
 from trytond.pool import Pool, PoolMeta
+from trytond.transaction import Transaction
 
 
 class Product(metaclass=PoolMeta):
@@ -10,22 +10,19 @@ class Product(metaclass=PoolMeta):
 
     def _get_sale_unit_price(self, quantity=0):
         pool = Pool()
+        Date = pool.get('ir.date')
         PriceList = pool.get('product.price_list')
-        Party = pool.get('party.party')
         Uom = pool.get('product.uom')
         Tax = pool.get('account.tax')
         User = pool.get('res.user')
         context = Transaction().context
+        today = Date.today()
 
         unit_price = super()._get_sale_unit_price(quantity=quantity)
 
         if context.get('price_list'):
             price_list = PriceList(context['price_list'])
             assert price_list.company == User(Transaction().user).company
-            if context.get('customer'):
-                customer = Party(context['customer'])
-            else:
-                customer = None
             context_uom = None
             if context.get('uom'):
                 context_uom = Uom(context['uom'])
@@ -35,10 +32,10 @@ class Product(metaclass=PoolMeta):
             uom = context_uom or self.sale_uom
             if uom.category != self.sale_uom.category:
                 uom = self.sale_uom
-            unit_price = price_list.compute(
-                 customer, self, unit_price, quantity, uom)
-            if price_list.tax_included and taxes:
-                unit_price = Tax.reverse_compute(unit_price, taxes)
+            unit_price = price_list.compute(self, quantity, uom)
+            if price_list.tax_included and taxes and unit_price is not None:
+                unit_price = Tax.reverse_compute(
+                    unit_price, taxes, today)
         return unit_price
 
 
